aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/core/platform/env_test.cc
diff options
context:
space:
mode:
authorGravatar Justine Tunney <jart@google.com>2017-04-13 14:04:22 -0800
committerGravatar TensorFlower Gardener <gardener@tensorflow.org>2017-04-13 15:29:45 -0700
commit34eb5f87279176269632f330cf0418310e3f0eca (patch)
treed945589f8077975b18e07aa573ef1a983ec8cbf9 /tensorflow/core/platform/env_test.cc
parente67bb079741b7bf8f54d63624b92d0cea4ef3a57 (diff)
Make SleepForMicroseconds test less flaky
Change: 153111659
Diffstat (limited to 'tensorflow/core/platform/env_test.cc')
-rw-r--r--tensorflow/core/platform/env_test.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/tensorflow/core/platform/env_test.cc b/tensorflow/core/platform/env_test.cc
index d0a249ddc1..b766c5d25b 100644
--- a/tensorflow/core/platform/env_test.cc
+++ b/tensorflow/core/platform/env_test.cc
@@ -253,10 +253,10 @@ TEST_F(DefaultEnvTest, SleepForMicroseconds) {
env_->SleepForMicroseconds(sleep_time);
const int64 delta = env_->NowMicros() - start;
// Subtract 50 from the sleep_time for this check because NowMicros can
// sometimes give slightly inconsistent values between the start and the
// finish (e.g. because the two calls run on different CPUs).
- EXPECT_GE(delta, sleep_time - 50);
+ EXPECT_GE(delta, sleep_time - 200);
}
class TmpDirFileSystem : public NullFileSystem {
@@ -253,10 +253,10 @@ TEST_F(DefaultEnvTest, SleepForMicroseconds) {
env_->SleepForMicroseconds(sleep_time);
const int64 delta = env_->NowMicros() - start;
- // Subtract 50 from the sleep_time for this check because NowMicros can
+ // Subtract 200 from the sleep_time for this check because NowMicros can
// sometimes give slightly inconsistent values between the start and the
// finish (e.g. because the two calls run on different CPUs).